<?php

declare(strict_types = 1);

namespace Drupal\linkychecker\Routing;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\Routing\EntityRouteProviderInterface;
use Symfony\Component\Routing\Route;
use Symfony\Component\Routing\RouteCollection;

/**
 * Route provider for Linkychecker.
 */
class LinkyCheckerRouteProvider implements EntityRouteProviderInterface {

  /**
   * {@inheritdoc}
   */
  public function getRoutes(EntityTypeInterface $entity_type) {
    $collection = new RouteCollection();

    $route = (new Route('/admin/content/linky/{linky}/crawl'))
      ->addDefaults([
        '_title' => 'Crawl',
        '_entity_form' => 'linky.linkychecker-crawl',
      ])
      ->setRequirement('_entity_access', 'linky.update')
      ->setOption('parameters', [
        'linky' => ['type' => 'entity:linky'],
      ]);
    $collection->add('entity.linky.linkychecker_crawl', $route);

    $route = (new Route('/admin/content/linky/{linky}/exclude'))
      ->addDefaults([
        '_title' => 'Exclude Link',
        '_entity_form' => 'linky.linkychecker-exclude',
      ])
      ->setRequirement('_entity_access', 'linky.update')
      ->setOption('parameters', [
        'linky' => ['type' => 'entity:linky'],
      ]);
    $collection->add('entity.linky.linkychecker_exclude', $route);

    $route = (new Route('/admin/content/linky/{linky}/include'))
      ->addDefaults([
        '_title' => 'Remove Exclusion Link',
        '_entity_form' => 'linky.linkychecker-include',
      ])
      ->setRequirement('_entity_access', 'linky.update')
      ->setOption('parameters', [
        'linky' => ['type' => 'entity:linky'],
      ]);
    $collection->add('entity.linky.linkychecker_include', $route);

    return $collection;
  }

}
